Bugs

cole Library Reference Manual
Prev |  | Next

# Chapter 4. Bugs

cole developers have done their best effort to fix all the bugs of cole. But may be some of the are still hidden in the code. If you found one (or many!), please send a report to the maintainer (<arturo@directmail.org>). When sending a report, please:

1. Describe with detail the behavior of cole and why you think it's a bug.

2. Configure cole using the argument --enable-verbose and send the output showing the bug.

3. Send the content of the variables cole_version and cole_host_info that the cole release you are using have. You wil have to write a little program to do this, but it will help much. =)

4. If you can, send the most small source code that shows the bug in action. May be you want to send the Structured Storage file you have been processing.

5. You can send the files `config.log` and `config.cache` (which were created by `configure`) if you want.

Thank you very much.

Following is the `BUGS` file for this release.

    Report bugs to the maintainer (see the file `AUTHORS' for details).
    Please, along with your detailed report, send the cole's output when compiled
    using `--enable-verbose' (see the files `README' and `INSTALL' for details).

    Current bugs:
    **************

    None.

    Fixed bugs:
    ************

    Reported that cole can't read files biggers that 8Mb. UPDATE: oledecod.c is
    changed now to read additional blocks to the bbd. This fixes the bug.

    Reported strange bug in cole 0.1.0 using Solaris using `../demo sprsheet.xls'
    in examples directory. We need more test there! UPDATE: Seems to be fixed in
    cole 1.0.0 with the endianess care code.

    Possible bugs:
    **************

    * cole is not reentrant safe (it's in TODO):
      What happend if, in any program, one user tries to decode and/or code
      two files (the same or diferent)? Because static vars, will it get
      broke? I think yes, mmmh...

Prev | Home | Next
Internals |  | Legal issues